@@ -1,6 +1,7 @@
 import dataclasses
 
 import jax
+import numpy as onp
 from jax import numpy as jnp
 from overrides import overrides
 
@@ -10,7 +11,7 @@ from .utils import get_epsilon, register_lie_group
 
 
 def _skew(omega: hints.Vector) -> hints.Matrix:
-    """Returns the skew-symmetric form of a length-3 vector. """
+    """Returns the skew-symmetric form of a length-3 vector."""
 
     wx, wy, wz = omega
     return jnp.array(
@@ -29,7 +30,7 @@ def _skew(omega: hints.Vector) -> hints.Matrix:
     space_dim=3,
 )
 @dataclasses.dataclass(frozen=True)
-class SE3(_base.SEBase):
+class SE3(_base.SEBase[SO3]):
     """Special Euclidean group for proper rigid transforms in 3D."""
 
     # SE3-specific
@@ -67,7 +68,7 @@ class SE3(_base.SEBase):
     @staticmethod
     @overrides
     def identity() -> "SE3":
-        return SE3(wxyz_xyz=jnp.array([1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]))
+        return SE3(wxyz_xyz=onp.array([1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]))
 
     @staticmethod
     @overrides
